#
# spec file for package swayidle
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           swayidle
Version:        1.8.0
Release:        1.7
Summary:        Idle management daemon for Wayland
License:        MIT
Group:          System/GUI/Other
URL:            https://github.com/swaywm/swayidle
Source0:        %{url}/archive/%{version}.tar.gz
BuildRequires:  meson >= 0.48.0
BuildRequires:  pkgconfig
BuildRequires:  scdoc
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-protocols) >= 1.14
BuildRequires:  pkgconfig(xkbcommon)
Suggests:       %{name}-bash-completion
Suggests:       %{name}-fish-completion
Suggests:       %{name}-zsh-completion

%description
sway's idle management daemon. It is compatible with any Wayland compositor which implements the KDE idle protocol.

%package bash-completion
Summary:        Bash completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
BuildArch:      noarch

%description bash-completion
Bash command line completion support for %{name}.

%package fish-completion
Summary:        Fish completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
BuildArch:      noarch

%description fish-completion
Fish command line completion support for %{name}.

%package zsh-completion
Summary:        Zsh completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
BuildArch:      noarch

%description zsh-completion
Zsh command line completion support for %{name}.

%prep
%autosetup -p1

%build
export CFLAGS="%{optflags} -I/usr/include/wayland"
%meson
%meson_build

%install
%meson_install

%files
%{_bindir}/swayidle
%{_mandir}/man1/swayidle.1%{?ext_man}

%files bash-completion
%{_datadir}/bash-completion/completions/

%files fish-completion
%dir %{_datadir}/fish/
%{_datadir}/fish/vendor_completions.d/

%files zsh-completion
%{_datadir}/zsh/site-functions/

%changelog
* Tue Dec  6 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.8.0:
  * bash-completion: localize variables
  * Fix segfault when no arg is given and no config file exists
  * Add support for ext-idle-notify-v1
  * Fix printf using size_t lineno variable
- Remove e81d40fca7533f73319e76e42fa9694b21cc9e6e.patch
* Thu Jan 20 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add e81d40fca7533f73319e76e42fa9694b21cc9e6e.patch: Fix printf
  using size_t lineno variable.
* Mon Jan 17 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.7.1:
  * Add editorconfig
  * Improve log messages
  * Call release() to let the server remove the timer.
  * Allow forked processes to receive signal
* Tue Aug 17 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.7:
  * swayidle can be configured in a file instead of CLI arguments
  * The seat can be selected with the -S flag
  * logind idle inhibitors are now supported
- Remove swayidle-version.patch: upstreamed
* Thu Jan 23 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.6:
  * Add logind SetIdleHint event
  * completion: use pkg-config to get install location for bash/fish
  * fish-completion: use the correct fallback directory
  * Update bash and fish completions with option -w
  * Update zsh completions
- Add swayidle-version.patch
  See https://github.com/swaywm/swayidle/pull/53
* Thu Dec 19 2019 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(libsystemd) instead of systemd-devel:
  Allow OBS to shortcut through the -mini flavors.
* Fri Jul 12 2019 mvetter@suse.com
- Update to 1.5:
  * Set version to 1.5
- Remove swayidle-version.patch: upstreamed
* Thu Jul 11 2019 mvetter@suse.com
- Update to 1.4:
  * Adapt version number to actual release
  * Remove space in scdoc preamble
* Thu May 23 2019 mvetter@suse.com
- Update to 1.3:
  * Add an error message when before-sleep is used without dbus support
  * Add support for logind's lock/unlock signals
  * Set version in project file
- Add swayidle-version.patch: they forgot to increase the version
* Thu Feb  7 2019 Jan Engelhardt <jengelh@inai.de>
- Update RPM groups.
* Thu Feb  7 2019 mvetter@suse.com
- Put bash/fish/zsh completion in their own packages
* Tue Feb  5 2019 mvetter@suse.com
- Update to 1.2:
  * Use -Wvla flag to prevent usage of VLAs.
  * update example to include a recommended -w option in swayidle
  * Replace old Sway references with swayidle
  * meson: add a logind feature
  * introduce an after-resume argument
  * implement after-resume hook
  * make sure we run when only after-resume is used
  * use sd_bus_match_signal instead of sd_bus_add_match
  * rename state.lock_cmd to state.before_sleep_cmd
* Mon Feb  4 2019 mvetter@suse.com
- Initial package swayidle 1.1 for openSUSE
